function [emissions] = emissions_calc(fuelcons,energy,MCR,fueltype)

% EMISSIONS_CALC.m calculates the emissions of CO2, NOx, SOx and PM for a
% given fuel consumption and energy use for the case ship.
% 
% -------------------------------------------------------------------
% Input
%
% fuelcons   Fuel consumption on leg                 kg
% energy     Energy used on leg                      kWh
% MCR        Percentage of MCR used on leg           percent
% fueltype   Type of fuel used on leg (HFO, MGO or
%            LNG), input as string    
%
% -------------------------------------------------------------------
% Output
%
% CO2        Total emissions on leg                  g
% NOx        Total emissions on leg                  g
% SOx        Total emissions on leg                  g
% PM         Total emissions on leg                  mg
% -------------------------------------------------------------------
% Runa A. Skarb | runaaman@stud.ntnu.no | v1.0 03 Dec 2014

% Load datafile with emission values
eng = load('enginedata.mat');

% Names of variables needed from L2
NOxvar = sprintf('p_NOx_%s', fueltype);
PMvar  = sprintf('p_PM_%s', fueltype);

% Find NOx and PM specific emissions for given MCR
speNOx = polyval(eng.(NOxvar), MCR); % g/kWh
spePM  = polyval(eng.(PMvar), MCR);  % mg/kWh

% Find sulphur percentage in fuel
S_perc = eng.sulphur.(fueltype); % percent

% Emissions; CO2, SOx, NOx (g) and PM (mg)
CO2 = eng.PER.CO2.(fueltype) * fuelcons;
SOx = eng.PER.SOx.(fueltype) * S_perc * fuelcons;
NOx = speNOx * energy;
PM  = spePM  * energy;

emissions = [CO2,NOx,SOx,PM];

end