function [iceT,iceC] = findice(leg,date)

% FINDICE.m interpolates to determine the ice conditions for a given date
% on a certain leg on the NSR. A linear relationship for ice growth is
% assumed.
%
% ----------------------------------------------------------------------
% Outputs:
%
% iceT       Ice thickness                     cm
% iceC       Ice consentration                 cm
%
% ----------------------------------------------------------------------
% Inputs:
%
% leg        Leg number on the icedata vector
% date       Current date in serial date       
%            number format
%
% ----------------------------------------------------------------------
% Runa A. Skarb | runaaman@stud.ntnu.no | v1.0, 04 Dec 2014

icedata = load('icedata.mat');

datevec = icedata.ice_dates;
iceTvec = icedata.ice_t;
iceCvec = icedata.ice_c;

if date < datevec(1) || date > datevec(length(datevec))
    error('Date outside date range for measurements')
    return
end

% Find closest date to current date
[~,idx1] = min(abs(datevec - date));

% Find other date to interpolate between
if date < datevec(idx1) 
    idx2 = idx1 - 1;
else
    idx2 = idx1 + 1;
end

% Find ice conditions for current date
iceT = interp1([datevec(idx1), datevec(idx2)], ...
    [iceTvec(leg,idx1), iceTvec(leg,idx2)], date);
iceC = interp1([datevec(idx1), datevec(idx2)], ...
    [iceCvec(leg,idx1), iceCvec(leg,idx2)], date);

end