% HV_INPUT.m generate the input required for HV.m,
% - give the input for the script HV.m,
% - saves the calculated values from HV.m to the file 'hv.mat',
% - plots curves for net thrust, ice resistance and the hv-curve (optional)
% - saves plots as png

clear; 
%% Give  input for the script HV.m
load('variables.mat','V_max','Lbp','Loa','B','T');

V = V_max;

Lpar = 164.4;  % Parallel midbody length, m
phi  = 40;         % Stem angle, deg
alpha = 48;

PB   = 13560;      % Engine power, kW
Dp   = 7.5;        % Propeller diameter, m. 
Ke    = 0.78*0.9;   % Empirical factor for bollard pull (see Juva and Riska, 2002)

[h, V, Tnet, Ri] = hv(V, Lbp, B, T, Lpar, phi, alpha, PB, Dp, Ke);

%% Save hv-curve values
save('hv.mat','h','V','Tnet','Ri','-v7.3')

%% Plot curves for net thrust, ice resistance and hv-curve 
%{
clf;
% Plot net thrust vs V
thrust = figure(1);
hold on
handle1 = plot(V,Tnet);
xlabel('Speed, kn')
ylabel('Net thrust, kN')
title('Thrust available to overcome ice resistance')

% Plot channel ice resistance vs ice thickness
ice = figure(2);
hold on
handle2 = plot(h,Ri);
xlabel('Ice thickness, m')
ylabel('Resistance, kN')
title('Brash ice resistance')
%%}

% h-v curve plot
hv = figure(3); 
hold on
plot(V,h);
%plot([5 5],ylim,'k','LineStyle','--'); % Lower speed limit
xlabel('Speed, kn')
ylabel('Ice thickness, m')
title('Attainable speed in brash ice')


%}
%% Save plots as png
%{
saveas(thrust,'Tnet','png');
saveas(ice,'iceresistance','png');
saveas(hv,'hvcurve','png');
%}

