% ICE_PLOT.m plot the data points for both ice data and route data (NSR)in
% a map. 
%
% Requirements:
% - Mapping Toolbox

clear;

icedata = load('icedata.mat');
routedata = load('routedata.mat');

%% Sort geographic data, ice

% Sort latitude coordinates in separate coloumns for east and west
lat_ice = [icedata.ice_coord(:,1).*(icedata.ice_coord(:,1)>0) ...
           icedata.ice_coord(:,1).*(icedata.ice_coord(:,1)<0)];
lat_ice(~lat_ice) = nan;

% Sort longitude coordinates in separate coloumns for north and south 
lon_ice = [icedata.ice_coord(:,2).*(icedata.ice_coord(:,2)>0) ...
           icedata.ice_coord(:,2).*(icedata.ice_coord(:,2)<0)];
lon_ice(~lon_ice) = nan;

% Determine outer limits for the route
latlim = [min(lat_ice) ; max(lat_ice)];
lonlim = [min(lon_ice) ; max(lon_ice)];

%% Plot map of ice data region

% NB: Does not work with coordinates < 0 deg N!
LatLimMap = [floor(min(latlim(:,1)-2)/2)*2 ...
             ceil(max(latlim(:,1)+2)/2)*2 ];
LonLimMap = [floor((routedata.coord.Murmansk(2)-5)/5)*5 ...
             ceil(max(lonlim(:,2)+5)/5)*5 ];
ice_data = worldmap(LatLimMap,LonLimMap);


% Display land areas as green
geoshow('landareas.shp','FaceColor','green')

% Display details 
%{
% Display rivers
geoshow('worldrivers.shp')  

% Display coast lines
load coast
plotm(lat, long,'Color','black')
 
% Display topography
load topo
geoshow(topo, topolegend, 'DisplayType', 'texturemap')
demcmap(topo)
%brighten(.3)
%}
 
% Display Murmansk with label
plotm(routedata.coord.Murmansk, 'yo', 'MarkerFaceColor','auto')
textm(routedata.coord.Murmansk(1)-5, routedata.coord.Murmansk(2)+1, ...
      'Murmansk','BackgroundColor','w')
 
% Plot ice data point coordinates
icehandle = plotm(icedata.ice_coord,'r.')
hold on
% Plot route data
routehandle = plotm(routedata.route.legcoordinates.NSR,'b')

legend([icehandle, routehandle],'Ice data points','Shortest route','Location','best')
title('Ice data points and generated route')

% Save plot
%{
saveas(ice_data,'icedatavsroute','png')
%}