% MAINDIM.m define the properties for the case vessel and calculates the open
% water resistance using OW_RESISTANCE.m.
%
% ----------------------------------------------------------------------
% Runa A. Skarb | runaaman@stud.ntnu.no | v1.3, 04 Nov 2014

clear; 
%% Define vessel dimensions
% Input values are read from files defined from Excel.
 %{
    % Vessel input
    [vfile,msg] = fopen('vessel_input.txt','r');
    vessel_input = fscanf(vfile,
    status = fclose(vfile);
    
    % Route input
    [rfile,msg] = fopen('route_input.txt','r');
    route_input = fscanf(rfile,
    status = fclose(rfile);
%}    

% Vessel dimensions must me manually defined below until reading is fixed

% Dimensions
Loa = 225  ; % m
Lbp = 220  ; % m
Lwl = 221  ; % m
B   =  32.3; % m
T   =  14.1; % m

% Weights
dwt = 75603; % tonne
wls = 14950; % tonne

GT = 41142;
NT = 25265;

% Speed
V_s   = 14.5; % kn (service speed)
V_max = 15.4; % kn

% Propeller diameter
D_p =   7.5;  % m

voldispl    = 88344; % m^3
weightdispl = 90553; % tonne

% Hull coefficients
Cb = 0.878;
Cm = 0.98 ;
Cp = Cb/Cm;

% Wet surface
wetsurf = 2.73 * sqrt(voldispl * Lwl); % m^2

%% Calculate open water resistance
% This section uses the script ow_resistance.m to calculate the open water
% resistance for the case ship. The resistance in ice is found with the
% script ice_resistance.m.

% Open water resistance
plot_Rt   = 0;  % = 1 if output plot of Rt, = 0 otherwise
plot_coef = 0;  % = 1 if output plot of resistance coefficients, = 0 otherwise
[V_vec, Row] = ow_resistance(Lwl,B,T,V_max,wetsurf,plot_Rt,plot_coef);
clear plot_Rt plot_coef

%% Save variables to file 'variables.mat'
% This section saves the variables generated in this script, to avoid
% running the script at every startup
save('shipdata.mat','-v7.3');

%{
%% Calculate resistance in ice
% Coefficients for ice resistance calculations:
alpha = 48;   % deg
phi2 = 40;    % deg
Lpar = 164.4; % m
H_M = linspace(0,200); % Ice thickness vector (up to 2 m)
Ri = ice_resistance(H_M,phi2,alpha,Lbp,B,T,Lpar);
    
%% Map route with /MAPPINGFOLDER/ROUTEDATA.M
% This section use the mapping toolbox to generate the route
cd mappingfolder
routedata
cd ..
%}