% SAILSCR.m is a part of the SIMULATE_SAILING.m-script. It simulates the
% sailing on the SCR route.
%%{

numtrips = numtrips + 1;

voyagefc = struct;
voyagefc.(burnfuel) = zeros(1,2);
voyagefc.(burnECAfuel) = zeros(1,2);
voyageem = zeros(2,4);
cumdist   = 0;

route = 'SCR';
forindex = (1:length(routedata.dist.(route)));

% Check for which direction the vessel sails. If sails from
% Tianjin to M, the for loop shall count backwards:
port = char(posvec(pos));
switch port
    case 'Tianjin'
        forindex = flipud(forindex);
end

starttime = time;

for k = forindex
    fueltype = burnfuel;                    
    distance = routedata.dist.SCR(k);

    % Determine use of ECA technology (NOTE! ONLY SECA ON SCR)
    if (~ismember(k, routedata.ECA.SCRi) && ismember(k+1, routedata.ECA.SCRi)) || ... % vessel not in ECA, but enters on next leg (must switch on this leg) OR
            (ismember(k, routedata.ECA.SCRi) && ismember(k+1, routedata.ECA.SCRi)) || ... % vessel is in ECA and next leg is also in ECA (use ECA tech) OR 
            (ismember(k, routedata.ECA.SCRi) && ~ismember(k+1, routedata.ECA.SCRi)) % vessel is in ECA and next leg is not in ECA (switch when outside ECA)
        fueltype = burnECAfuel;
        SOxtech  = scenarios.(scenarioname).SOxtech;
        
    else % vessel is outside ECA
        SOxtech  = 'none';
    end
        
    % Determine speed limits on leg
    if routedata.speedlim.(route)(k) > 0
        V_leg = routedata.speedlim.(route)(k);
    else
        V_leg = shipdata.V_s;
    end
    
    % Simulate sailing on leg
    [t_leg, fc_before, emissions_before, energy] = sail_ow(V_leg, distance, fueltype);

    % Change in fc due to abatement technologies (if no
    % technology, then change is defined as 0 % in input
    % file) 
    fc_after = fc_before * (1+0.01 * atechdata.(SOxtech).addfc);

    % Reduction of emissions due to abatement technologies
    % CO2
    emissions_after(1) = emissions_before(1);

    % SOx
    emissions_after(2) = emissions_before(2) * (1+0.01 * atechdata.(SOxtech).SOxred);

    %NOx
    emissions_after(3) = emissions_before(3) * (1+0.01 * atechdata.(SOxtech).NOxred);

    %PM
    emissions_after(4) = emissions_before(4) * (1+0.01 * atechdata.(SOxtech).PMred);

    % In case of negative emissions
    for i = 2:length(emissions_after)
        if emissions_after(i) < 0
            emissions_after(i) = 0;
        end
    end

    % Save sailing info for leg
    simulationresults.(scenarioname).tourdata(numtrips).legdata(k).time                         = t_leg;
    simulationresults.(scenarioname).tourdata(numtrips).legdata(k).fuelconsumption.(fueltype)   = [fc_before, fc_after];
    simulationresults.(scenarioname).tourdata(numtrips).legdata(k).emissions                    = [emissions_before; emissions_after];
    simulationresults.(scenarioname).tourdata(numtrips).legdata(k).energy                       = energy;    

    % Save cumulative info for voyage
    voyageem            = voyageem + simulationresults.(scenarioname).tourdata(numtrips).legdata(k).emissions;
    voyagefc.(fueltype) = voyagefc.(fueltype) + simulationresults.(scenarioname).tourdata(numtrips).legdata(k).fuelconsumption.(fueltype);
    cumdist             = cumdist + distance;
    
    % Cumulative time for simulations
    time = time + t_leg;
end

% Save sailing info for voyage
simulationresults.(scenarioname).tourdata(numtrips).route                           = route;
simulationresults.(scenarioname).tourdata(numtrips).starttime                       = starttime;
simulationresults.(scenarioname).tourdata(numtrips).endtime                         = time;
simulationresults.(scenarioname).tourdata(numtrips).duration                        = time - starttime;
simulationresults.(scenarioname).tourdata(numtrips).startpos                        = char(posvec(pos));
simulationresults.(scenarioname).tourdata(numtrips).emissions                       = voyageem;

% If fuel in ECA is same as outside ECA
if strcmp(burnfuel,burnECAfuel)
    % Data for voyage
    simulationresults.(scenarioname).tourdata(numtrips).fuelconsumption.(burnfuel) = voyagefc.(burnfuel);
    % Cumulative data for scenario
    scenariofc.(burnfuel) = scenariofc.(burnfuel) + voyagefc.(burnfuel);
else
    % Data for voyage
    simulationresults.(scenarioname).tourdata(numtrips).fuelconsumption.(burnfuel)    = voyagefc.(burnfuel);
    simulationresults.(scenarioname).tourdata(numtrips).fuelconsumption.(burnECAfuel) = voyagefc.(burnECAfuel);
    
    % Cumulative data for scenario
    scenariofc.(burnfuel)    = scenariofc.(burnfuel)    + voyagefc.(burnfuel);
    scenariofc.(burnECAfuel) = scenariofc.(burnECAfuel) + voyagefc.(burnECAfuel);
end

% Other cumulative data for scenario
scenarioem = scenarioem + voyageem;

% Change position and keep inventory
switch pos
    case 1
        tripsMT = tripsMT + 1;
        pos = 2;
    otherwise
        tripsTM = tripsTM + 1;
        pos = 1;
end
%}













